@@ -287,6 +287,8 @@ sub load {
     $info = $self->api_info->{$self->base_role};
     $key = $info->{key};
 
+    return unless $self->$key;
+
     $field_ref = $self->_db_fields;
 
     $sql = $self->_build_query('select',
@@ -700,7 +702,12 @@ sub _manage_assignments {
 
     # handle subclassed Nitesi roles
     if (exists $info_from->{base}) {
-        $role_from = $info_from->{base};
+        if (exists $info->{assign}->{$info_from->{base}}) {
+            $role_from = $info_from->{base};
+        }
+        else{
+            $role_from = $info_from->{inherit};
+        }
     }
 
     # determine assignment parameters
